abjadbooktools.CodeBlock
========================

.. inheritance-diagram:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock
   :private-bases:

.. autoclass:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.ending_line_number

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.hide

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.lines

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.processed_results

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.starting_line_number

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.strip_prompt

Methods
-------

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.read

Special Methods
---------------

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__call__

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__eq__

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.CodeBlock.CodeBlock.CodeBlock.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
